@@ -1,13 +1,8 @@
-from typing import List, Dict
-
 from pydantic import BaseModel
-from pydantic.types import FilePath
 
 from core.constructs.workspace import Workspace, Workspace_Info
 
 
-
-
 class environment_info(BaseModel):
     """
     Represents the information about an environment.
@@ -20,15 +15,9 @@ class environment_info(BaseModel):
     name: str
     workspace_info: Workspace_Info
 
-    def __init__(
-        __pydantic_self__,
-        name: str,
-        workspace_info: Workspace_Info
-        ) -> None:
+    def __init__(__pydantic_self__, name: str, workspace_info: Workspace_Info) -> None:
 
-        super().__init__(
-            **{"name": name, "workspace_info": workspace_info}
-        )
+        super().__init__(**{"name": name, "workspace_info": workspace_info})
 
 
 class Environment:
@@ -39,8 +28,22 @@ class Environment:
     def __init__(self, info: environment_info) -> None:
         pass
 
-    def get_workspace(self) -> Workspace:
+    def get_name(self) -> str:
+        """Return the name of the Environment
+
+        Returns:
+            str: name of the Environment
+        """
         raise NotImplementedError
 
-    def initialize_environment(self):
+    def get_workspace(self) -> Workspace:
+        """Get the Workspace associated with this Environment
+
+        Returns:
+            Workspace
+        """
+        raise NotImplementedError
+
+    def initialize_environment(self) -> None:
+        """Initialize the Environment"""
         raise NotImplementedError
