@@ -6,6 +6,7 @@ from pydantic import DirectoryPath
 from pydantic.types import FilePath
 from sortedcontainers.sortedlist import SortedKeyList
 from functools import partial
+from pathlib import Path
 
 from core.constructs.resource import (
     Resource,
@@ -278,7 +279,9 @@ def _parse_serverless_functions(
     """
     full_file_path = paths.get_full_path_from_workspace_base(filepath)
     excludes = {"__pycache__"}
-    aws_platform_exclude = {"boto3"}
+    aws_platform_exclude = (
+        set() if Workspace.instance().settings.PACKAGE_AWS_PACKAGES else {"boto3"}
+    )
 
     (
         std_lib,
@@ -315,7 +318,7 @@ def _parse_serverless_functions(
 
     mod_creator = partial(
         package_manager.create_all_module_info,
-        start_location=full_file_path,
+        start_location=Path(full_file_path).parent,
         standard_library=std_lib,
         pkg_dependencies_data=pkg_module_dependency_info,
         pkg_locations=modules_name_to_location,
@@ -558,6 +561,8 @@ def _create_new_configuration(
         storage=previous_configuration.storage,
         description=previous_configuration.description,
         environment_variables=previous_configuration.environment_variables,
+        subnets=previous_configuration.subnets,
+        security_groups=previous_configuration.security_groups,
     )
 
 
