@@ -97,7 +97,7 @@ def create_all_module_info(
 
 def get_packaged_modules_name_location_tag(
     working_set: WorkingSet,
-) -> Dict[str, Tuple[FilePath, str]]:
+) -> Dict[str, Tuple[FilePath, str, str]]:
     """Generate the file system location information for modules in a working set.
 
     Returns:
@@ -141,7 +141,6 @@ def create_packaged_module_dependencies(ws: WorkingSet) -> Dict[str, Set[str]]:
         Dict[str, List[str]]: <module_name, all modules it depends on>
     """
     pkgs_to_top_mods = _create_pkg_to_top_modules(ws)
-
     return combine_dictionaries(
         [_get_module_dependencies_info(x, pkgs_to_top_mods, ws) for x in ws]
     )
@@ -191,14 +190,24 @@ def _get_all_module_info(
     referenced_pkged_module_names: Set[str] = set(packaged_mod_names)
 
     # Find the relative dependencies in a module
+
     for relative_module in direct_relative_modules:
+
+        l, p = _parse_levels(relative_module.module_name)
+        t = (Path(relative_module.absolute_fs_position).parent,)
+        new_relative_path = move_to(str(t[0]), l, p[:-1])
+
         (
             tmp_relative_module_dependencies,
             tmp_pkged_mod_names,
             tmp_std_lib_mods,
             cache,
         ) = _recursive_find_relative_module_dependencies(
-            relative_module, module_segmenter, module_creator, cache
+            relative_module,
+            module_segmenter,
+            module_creator,
+            cache,
+            new_relative_path,
         )
 
         # add the newly found relative modules to the set of relative modules
@@ -261,10 +270,16 @@ def _create_module_info(
         return _create_std_library_module_info(module_name)
 
     elif module_name in packaged_module_locations_tags:
-        location, tag = packaged_module_locations_tags.get(module_name)
-        return _create_packaged_module_info(
-            module_name, _get_module_abs_path(module_name, location), tag
+        location, tag, namespace = packaged_module_locations_tags.get(module_name)
+        x = _create_packaged_module_info(
+            module_name,
+            _get_module_abs_path(module_name, location)
+            if not namespace
+            else _get_module_abs_path(namespace, location),
+            tag,
+            namespace,
         )
+        return x
 
     else:
         raise PackagingError(
@@ -316,6 +331,7 @@ def _recursive_find_relative_module_dependencies(
     module_segmenter: module_segmenter,
     module_creator: module_info_creator,
     cache: Dict,
+    update_relative_path: Path = None,
 ) -> Tuple[Set[RelativeModuleInfo], Set[str], Set[StdLibModuleInfo], Dict]:
     """For the given RelativeModuleInfo Object, find the information about any modules that it links to.
 
@@ -352,6 +368,10 @@ def _recursive_find_relative_module_dependencies(
         std_dependencies_names,
     ) = module_segmenter(direct_dependencies)
 
+    # Update the module creator to point to the new base directory for relative imports
+
+    module_creator = partial(module_creator, start_location=update_relative_path)
+
     # Sets we will add to for each type of module
     rv_relative_dependencies: Set[RelativeModuleInfo] = set(
         [module_creator(x) for x in relative_dependencies_names]
@@ -363,18 +383,21 @@ def _recursive_find_relative_module_dependencies(
 
     # For the relative dependencies, Recursively find any other modules needed
     for relative_dependency in relative_dependencies_names:
-        tmp = _recursive_find_relative_module_dependencies(
-            module_creator(relative_dependency),
-            module_segmenter,
-            module_creator,
-            cache_copy,
-        )
+        l, p = _parse_levels(relative_dependency)
+        new_relative_path = move_to(update_relative_path, l, p)
+
         (
             tmp_relative_dependencies,
             tmp_packaged_dependencies,
             tmp_std_dependencies,
             cache_copy,
-        ) = tmp
+        ) = _recursive_find_relative_module_dependencies(
+            module_creator(relative_dependency),
+            module_segmenter,
+            module_creator,
+            cache_copy,
+            new_relative_path,
+        )
 
         rv_relative_dependencies.update(tmp_relative_dependencies)
         rv_packaged_dependencies_names.update(tmp_packaged_dependencies)
@@ -394,8 +417,6 @@ def _recursive_find_relative_module_dependencies(
 
 
 ### Create Module Info Object
-
-
 def _create_relative_module_info(
     module_symbol: str, original_file_location: FilePath
 ) -> RelativeModuleInfo:
@@ -416,7 +437,13 @@ def _create_relative_module_info(
 
     original_path = Path(original_file_location)
     # go up the amount of levels need to get to the top of the search path
-    relative_base_dir = original_path.parents[relative_level - 1]
+    relative_base_dir = (
+        original_path.parents[relative_level - 1]
+        if relative_level > 3
+        else original_path.parent
+        if relative_level == 2
+        else original_path
+    )
 
     # remove leading '.' chars, the remaining portion is the path to search down from the top
     tmp_pkg_path_parts = str(module_symbol).lstrip(".").split(".")
@@ -436,7 +463,9 @@ def _create_relative_module_info(
         fp = tmp_potential_dir
         is_dir = True
     else:
-        raise Exception(f"Bad relative module: {module_symbol}")
+        raise Exception(
+            f"Bad relative module: {module_symbol}; {tmp_potential_dir}; {tmp_potential_file}"
+        )
 
     return RelativeModuleInfo(
         module_name=module_symbol, absolute_fs_position=fp, is_dir=is_dir
@@ -444,7 +473,7 @@ def _create_relative_module_info(
 
 
 def _create_packaged_module_info(
-    module_symbol: str, filepath: FilePath, tag: str
+    module_symbol: str, filepath: FilePath, tag: str, namespace: str
 ) -> PackagedModuleInfo:
     """Create a PackagedModuleInfo object
 
@@ -452,6 +481,7 @@ def _create_packaged_module_info(
         module_symbol (str): symbol used to import module
         filepath (FilePath): Filesystem location of the module
         tag (str): tags from the package
+        namespace (str): namespace for the module
 
     Returns:
         PackagedModuleInfo
@@ -463,7 +493,11 @@ def _create_packaged_module_info(
         is_dir = True
 
     return PackagedModuleInfo(
-        module_name=module_symbol, absolute_fs_position=filepath, is_dir=is_dir, tag=tag
+        module_name=module_symbol,
+        absolute_fs_position=filepath,
+        is_dir=is_dir,
+        tag=tag,
+        namespace=namespace,
     )
 
 
@@ -505,7 +539,7 @@ def _create_packages_direct_modules(dependency: Distribution) -> List[str]:
     Returns:
         List[str]: top level modules
     """
-    _, top_level_fp, _, _ = _get_metadata_files_for_package(dependency)
+    _, top_level_fp, _, _, _ = _get_metadata_files_for_package(dependency)
 
     if top_level_fp == None:
         # Problem when Cdev is locally linked... #TODO find more permanent solution
@@ -579,11 +613,11 @@ def _recursive_get_all_dependencies(
 
 def _get_packages_modules_location_tag_info(
     package: Distribution,
-) -> Dict[str, FilePath]:
+) -> Dict[str, Tuple[str, str, str]]:
     """Get all the top level modules available from a given package
 
     Returns:
-        List[Tuple[str, List[str]]]: List of tuples of (name, List[tags])
+        Dict[str, Tuple[str,str, str]]: Dict of module name to  (module_location, tags, namespace)
     """
     # For information on this object check
     # https://setuptools.pypa.io/en/latest/pkg_resources.html#distribution-objects
@@ -593,6 +627,7 @@ def _get_packages_modules_location_tag_info(
         _,
         toplevel_location,
         wheel_location,
+        record_location,
         base_directory_location,
     ) = _get_metadata_files_for_package(package)
 
@@ -602,16 +637,30 @@ def _get_packages_modules_location_tag_info(
 
     tags = "-".join(_get_tags_from_wheel(wheel_location))
 
+    _actual_top_level_modules = _find_module_locations_from_record(record_location)
+
     if not os.path.isfile(toplevel_location):
         # If not top level file is present, then assume the only top level module available is the
-        # project name properly converted
-        return {package.project_name.replace("-", "_"): (base_directory_location, tags)}
+        # project name properly converted or a namespace
+
+        _converted_package_name = package.project_name.replace("-", "_")
+
+        if _converted_package_name in _actual_top_level_modules:
+            return {_converted_package_name: (base_directory_location, tags, None)}
+        else:
+            # This is a namespace package (https://packaging.python.org/en/latest/guides/packaging-namespace-packages/)
+            _namespace = _actual_top_level_modules.pop()
+            return {
+                _converted_package_name: (base_directory_location, tags, _namespace)
+            }
 
     with open(toplevel_location) as fh:
         # read the top_level file for all the modules directly available in this package
         top_level_mod_names = fh.readlines()
 
-    return {x.strip(): (base_directory_location, tags) for x in top_level_mod_names}
+    return {
+        x.strip(): (base_directory_location, tags, None) for x in top_level_mod_names
+    }
 
 
 def _get_metadata_files_for_package(
@@ -623,7 +672,7 @@ def _get_metadata_files_for_package(
         package (Distribution)
 
     Returns:
-        Tuple[str,str,str, FilePath]: Distinfo_folder, TopLevel_fileloc, Wheel_fileloc, base_dir
+        Tuple[str,str,str,str,FilePath]: Distinfo_folder, TopLevel_fileloc, Wheel_fileloc, Record_fileloc base_dir
     """
 
     # find the dist info directory that will contain metadata about the package
@@ -634,15 +683,17 @@ def _get_metadata_files_for_package(
 
     if not os.path.isdir(dist_dir_location):
         # raise Exception(f"No .distinfo found for {package}")
-        return None, None, None, None
+        return None, None, None, None, None
 
     toplevel_file_location = os.path.join(dist_dir_location, "top_level.txt")
     wheel_info = os.path.join(dist_dir_location, "WHEEL")
+    record_info = os.path.join(dist_dir_location, "RECORD")
 
     return (
         dist_dir_location,
         toplevel_file_location,
         wheel_info,
+        record_info,
         package.location if not package.location == "none" else None,
     )
 
@@ -721,6 +772,7 @@ def _get_module_abs_path(module_name: str, base_path: FilePath) -> FilePath:
     elif os.path.isfile(potential_file):
         return potential_file
     else:
+        # return base_path
         raise Exception(
             f"Could not find either {module_name}.py or {module_name} directory in {base_path}"
         )
@@ -759,6 +811,28 @@ def _get_relative_package_dependencies(fp: Union[FilePath, DirectoryPath]) -> Li
     return list(filter(None, module_names))
 
 
+def _find_module_locations_from_record(record_file_location: str) -> Set[str]:
+    """Given a RECORD file location, create a set of the actual top level module directory names. This is to account for namespaced packages like
+    google (protobuf).
+
+    Args:
+        record_file_location (str): RECORD file location
+
+    Returns:
+        List[str]: top level modules
+    """
+    with open(record_file_location, "r") as fh:
+        lines = fh.readlines()
+
+    _all_starting_paths = set([x.split(",")[0].split("/")[0] for x in lines])
+
+    _all_starting_paths = set(
+        [x[:-3] if x[-3:] == ".py" else x for x in _all_starting_paths]
+    )
+
+    return {x for x in _all_starting_paths if not x.split(".")[-1] == "dist-info"}
+
+
 #######################
 ##### Utilities
 #######################
@@ -797,3 +871,28 @@ def put_relative_modules_cache(
     new_cache[module.to_key()] = val
 
     return new_cache
+
+
+def _parse_levels(t: str) -> Tuple[int, List[str]]:
+    x = t.split(".")
+
+    if not x[0] == "":
+        return 0, x[:-1]
+
+    x2 = x[1:]
+    cnt = 0
+
+    while x2[0] == "":
+        cnt = cnt + 1
+        x2.pop(0)
+
+    return cnt, x2[:-1]
+
+
+def move_to(start: str, up_levels: int, down_dirs: List[str]) -> str:
+    base = Path(start).parents[up_levels - 1] if up_levels > 0 else Path(start)
+
+    for down in down_dirs:
+        base = base / down
+
+    return base
